package db_model

import (
	"database/sql"

	"gorm.io/gorm"
)

type User struct {
	Id        int          `gorm:"primaryKey;autoIncrement"`
	UserId    int          `gorm:"type:int;uniqueIndex:uidx_uid_cid;not null;comment:telegram用户id"`
	Username  string       `gorm:"type:text;not null;comment:telegram用户名"`
	FirstName string       `gorm:"type:text;not null;comment:telegram名字"`
	LastName  string       `gorm:"type:text;not null;comment:telegram姓氏"`
	ChatId    int          `gorm:"type:int;uniqueIndex:uidx_uid_cid;not null;comment:telegram群id"`
	LeftAt    sql.NullTime `gorm:"index;comment:退出时间"`
	gorm.Model
}

func (*User) TableName() string {
	return "telegram_task.user"
}

type Active struct {
	Id       int `gorm:"primaryKey;autoIncrement"`
	UserId   int `gorm:"type:int;uniqueIndex:uidx_uid_cid_day;not null;comment:telegram用户id"`
	ChatId   int `gorm:"type:int;uniqueIndex:uidx_uid_cid_day;not null;comment:telegram群id"`
	UnixDay  int `gorm:"type:int;not null;uniqueIndex:uidx_uid_cid_day;comment:unix day"`
	MsgCount int `gorm:"type:int;not null;comment:消息数"`
	gorm.Model
}

func (*Active) TableName() string {
	return "telegram_task.active"
}

type ChatGroup struct {
	Id          int    `gorm:"primaryKey;autoIncrement"`
	ChatId      int    `gorm:"type:int;uniqueIndex;not null;comment:telegram群id"`
	ChatTitle   string `gorm:"type:text;not null;comment:telegram群名"`
	Description string `gorm:"type:text;comment:群描述"`
	gorm.Model
}

func (*ChatGroup) TableName() string {
	return "telegram_task.chat_group"
}
